#!/bin/sh
set -ev

test $DARCS || DARCS=$PWD/../darcs

rm -rf tempA tempB
mkdir tempA tempB
cd tempA
$DARCS init
touch foo
$DARCS add foo
$DARCS record -a -m addA -A x
cd ../tempB
$DARCS init
$DARCS pull -a ../tempA
$DARCS remove foo
# rm foo
$DARCS record -a -m rmB -A x
cd ../tempA
$DARCS remove foo
$DARCS record -a -m rmA -A x
cd ../tempB
$DARCS pull -a ../tempA
cd ..
rm -rf tempA tempB

